@@ -26,9 +26,11 @@
 #' if (requireNamespace("outbreaks", quietly = TRUE)) {
 #'     data(ebola_sim_clean, package = "outbreaks")
 #'     dat <- ebola_sim_clean$linelist
-#'     i <- incidence(dat, date_index = "date_of_onset",
-#'                    groups = c("gender", "hospital"))
-#'
+#'     i <- incidence(
+#'         dat,
+#'         date_index = "date_of_onset",
+#'         groups = c("gender", "hospital")
+#'     )
 #'     get_count_variable_name(i)
 #'     get_group_names(i)
 #'     get_dates_name(i)
@@ -53,7 +55,7 @@ get_date_index_name <- function(x, ...) {
 #' @rdname accessors
 #' @export
 get_date_index_name.default <- function(x, ...) {
-    .stopf_argument("Not implemented for class [%s].", paste(class(x), collapse = ", "))
+    .stopf("Not implemented for objects of class <%s>.", toString(class(x)))
 }
 
 # -------------------------------------------------------------------------
@@ -82,7 +84,7 @@ get_count_variable_name <- function(x, ...) {
 #' @rdname accessors
 #' @export
 get_count_variable_name.default <- function(x, ...) {
-    .stopf_argument("Not implemented for class [%s].", paste(class(x), collapse = ", "))
+    .stopf("Not implemented for objects of class <%s>.", toString(class(x)))
 }
 
 # -------------------------------------------------------------------------
@@ -106,7 +108,7 @@ get_count_value_name <- function(x, ...) {
 #' @rdname accessors
 #' @export
 get_count_value_name.default <- function(x, ...) {
-    .stopf_argument("Not implemented for class [%s].", paste(class(x), collapse = ", "))
+    .stopf("Not implemented for objects of class <%s>.", toString(class(x)))
 }
 
 # -------------------------------------------------------------------------
@@ -130,7 +132,7 @@ get_group_names <- function(x, ...) {
 #' @rdname accessors
 #' @export
 get_group_names.default <- function(x, ...) {
-    .stopf_argument("Not implemented for class [%s].", paste(class(x), collapse = ", "))
+    .stopf("Not implemented for objects of class <%s>.", toString(class(x)))
 }
 
 # -------------------------------------------------------------------------
@@ -155,7 +157,7 @@ get_date_index <- function(x, ...) {
 #' @rdname accessors
 #' @export
 get_date_index.default <- function(x, ...) {
-    .stopf_argument("Not implemented for class [%s].", paste(class(x), collapse = ", "))
+    .stopf("Not implemented for objects of class <%s>.", toString(class(x)))
 }
 
 # -------------------------------------------------------------------------
@@ -184,7 +186,7 @@ get_count_variable <- function(x, ...) {
 #' @rdname accessors
 #' @export
 get_count_variable.default <- function(x, ...) {
-    .stopf_argument("Not implemented for class [%s].", paste(class(x), collapse = ", "))
+    .stopf("Not implemented for objects of class <%s>.", toString(class(x)))
 }
 
 # -------------------------------------------------------------------------
@@ -208,7 +210,7 @@ get_count_value <- function(x, ...) {
 #' @rdname accessors
 #' @export
 get_count_value.default <- function(x, ...) {
-    .stopf_argument("Not implemented for class [%s].", paste(class(x), collapse = ", "))
+    .stopf("Not implemented for objects of class <%s>.", toString(class(x)))
 }
 
 # -------------------------------------------------------------------------
@@ -232,7 +234,7 @@ get_groups <- function(x, ...) {
 #' @rdname accessors
 #' @export
 get_groups.default <- function(x, ...) {
-    .stopf_argument("Not implemented for class [%s].", paste(class(x), collapse = ", "))
+    .stopf("Not implemented for objects of class <%s>.", toString(class(x)))
 }
 
 # -------------------------------------------------------------------------
